@@ -21,8 +21,7 @@ from robot.libraries.BuiltIn import BuiltIn  # type: ignore
 
 from .type_converter import is_truthy, type_converter
 
-__version__ = "0.1.0"
-
+__version__ = "0.3.0"
 
 AssertionOperator = Enum(
     "AssertionOperator",
@@ -70,7 +69,18 @@ AssertionOperator.__doc__ = """
     | ``$=``              | ``should end with``, ``ends``     | Checks if returned value ends with expected value.                                 | ``re.search(f"{expected}$", value)`` |
     | ``matches``         |                                   | Checks if given RegEx matches minimum once in returned value.                      | ``re.search(expected, value)``       |
     | ``validate``        |                                   | Checks if given Python expression evaluates to ``True``.                           |                                      |
-    | ``evaluate``        |  ``then``                         | When using this operator, the keyword does return the evaluated Python expression. |                        |
+    | ``evaluate``        |  ``then``                         | When using this operator, the keyword does return the evaluated Python expression. |                                      |
+
+    Currently supported formatters for assertions are:
+    |     = Formatter =     |                      = Description =                       |
+    |  ``normalize spaces`` | Substitutes multiple spaces to single space from the value |
+    |       ``strip``       | Removes spaces from the beginning and end of the value     |
+    | ``apply to expected`` | Applies rules also for the expected value                  |
+
+    Formatters are applied to the value before assertion is performed and keywords returns a value where rule is
+    applied. Formatter is only applied to the value which keyword returns and not all rules are valid for all assertion
+    operators. If ``apply to expected`` formatter is defined, then formatters are then formatter are also applied to
+    expected value.
     """
 
 NumericalOperators = [
@@ -122,19 +132,40 @@ handlers: Dict[AssertionOperator, Tuple[Callable, str]] = {
 T = TypeVar("T")
 
 
+def apply_formatters(value: T, formatters: Optional[List[Any]]) -> Any:
+    if not formatters:
+        return value
+    for formatter in formatters:
+        value = formatter(value)
+    return value
+
+
+def apply_to_expected(expected: Any, formatters: Optional[List[Any]]) -> Any:
+    if not formatters:
+        return expected
+    for formatter in formatters:
+        if formatter.__name__ == "_apply_to_expected":
+            return apply_formatters(expected, formatters)
+    return expected
+
+
 def verify_assertion(
     value: T,
     operator: Optional[AssertionOperator],
     expected: Any,
     message: str = "",
     custom_message: Optional[str] = None,
+    formatters: Optional[list] = None,
 ) -> Any:
+
     if operator is None and expected:
         raise ValueError(
-            f"It is not possible perform assertion when operator is {operator} type({type_converter(operator)})"
+            "Invalid validation parameters. Assertion operator is mandatory when specifying expected value."
         )
     if operator is None:
         return value
+    expected = apply_to_expected(expected, formatters)
+    value = apply_formatters(value, formatters)
     if operator is AssertionOperator["then"]:
         return cast(T, BuiltIn().evaluate(expected, namespace={"value": value}))
     handler = handlers.get(operator)
